package Bencher::ScenarioR::RangeIterators::Startup;

our $VERSION = 0.003; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        errors => 8.5e-06,
        mod_overhead_time => 4.6,
        participant => "Range::ArrayIter",
        samples => 20,
        time => 10.4,
        vs_slowest => 1,
      },
      {
        errors => 8.7e-06,
        mod_overhead_time => 4.6,
        participant => "Range::Iterator",
        samples => 21,
        time => 10.4,
        vs_slowest => 1.01,
      },
      {
        errors => 1.8e-05,
        mod_overhead_time => 4.2,
        participant => "Range::Iter",
        samples => 21,
        time => 10,
        vs_slowest => 1,
      },
      {
        errors => 1.2e-05,
        mod_overhead_time => 0,
        participant => "perl -e1 (baseline)",
        samples => 20,
        time => 5.8,
        vs_slowest => 1.8,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "RangeIterators::Startup",
                                          },
      "func.bencher_version"           => undef,
      "func.code_startup"              => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 3290.155,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => 3258.557,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 3266.693,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => "3286.370",
                                              stepping                     => 7,
                                            },
                                          ],
      "func.elapsed_time"              => 0.975898027420044,
      "func.module_startup"            => 1,
      "func.module_versions"           => {
                                            "__PACKAGE__"                                => 1.041,
                                            "Bencher::Scenario::RangeIterators::Startup" => undef,
                                            "Benchmark::Dumb"                            => 0.111,
                                            "Devel::Platform::Info"                      => 0.16,
                                            "perl"                                       => "v5.26.0",
                                            "Range::ArrayIter"                           => 0.002,
                                            "Range::Iter"                                => 0.002,
                                            "Range::Iterator"                            => 0.002,
                                            "Sys::Info"                                  => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 3]],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "sonya",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-4.8.0-53-generic",
                                            kname    => "Linux",
                                            kvers    => "4.8.0-53-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 18.2,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "4.8.0-53-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 0,
      "func.scenario_module"           => "Bencher::Scenario::RangeIterators::Startup",
      "func.scenario_module_md5sum"    => "2333344e9903c1c06f491b5a078cd700",
      "func.scenario_module_mtime"     => 1555994658,
      "func.scenario_module_sha1sum"   => "d0bb8094f265edb8e987d9af6850a0541f839b04",
      "func.scenario_module_sha256sum" => "4e3e7cd75dbcf631ab267f423e1673317d692d311838c4700a76178f20302ede",
      "func.time_end"                  => 1555996961.14898,
      "func.time_factor"               => 1000,
      "func.time_start"                => 1555996960.17308,
      "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
      "table.field_units"              => [undef, "ms", "ms"],
      "table.fields"                   => [
                                            "participant",
                                            "time",
                                            "mod_overhead_time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
];

1;
# ABSTRACT: Benchmark startup overhead

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

